
Miyadaiku - Flexible static site generator for Jinja2 artists
=========================================================================

Miyadaiku is a static site generator.

- Contents are written in reStructuredText and YAML. Markdown, HTML, Jupyter Notebook will be supported soon.

- Generate index pages and Atom/RSS feeds for Blog sites.

- Use themes to customize site.

- Themes are writtem in Jinja2, and are installed as Python package from PyPI.

- Jinja2 templates can be embedded in contents files.

- Other dependencies such as jQuery or Bootstrap can be managed as Python packages too.

